@@ -187,6 +187,9 @@ class Component(pack.Pack):
             except access_common.ComponentUnavailable as e:
                 errors.append(e)
                 self.dependencies_failed = True
+            except vcs.VCSError as e:
+                errors.append(e)
+                self.dependencies_failed = True
         specs = self.getDependencySpecs(target)
         #dependencies = pool.map(
         dependencies = map(
@@ -436,7 +439,7 @@ class Component(pack.Pack):
             r = access.satisfyVersionFromSearchPaths(name, version_req, search_dirs, update_if_installed)
             if r:
                 return r
-            r = access.satisfyVersionByInstalling(name, version_req, working_directory)
+            r = access.satisfyVersionByInstalling(name, version_req, self.modulesPath())
             if not r:
                 logger.error('could not install %s' % name)
             return r
