@@ -10,9 +10,9 @@ import os
 import re
 
 # fsutils, , misc filesystem utils, internal
-from lib import fsutils
+from .lib import fsutils
 # validate, , validate things, internal
-from lib import validate
+from .lib import validate
 
 
 def addOptions(parser):
